@@ -14,3 +14,8 @@ is_character_or_null <- function(x) {
 is_flag <- function(x) {
   is.logical(x) && length(x) == 1 && !is.na(x)
 }
+
+is_count <- function(x) {
+  is.numeric(x) && length(x) == 1 && !is.na(x) &&
+    as.integer(x) == x
+}
